"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGDynamicTexture(QSGTexture):
    """
    https://doc.qt.io/qt-6/qsgdynamictexture.html

    **Detailed Description**

    To update the content of the texture, call **updateTexture** () explicitly.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    def __init__(self) -> None:
        ...

    def updateTexture(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgdynamictexture.html#updateTexture

        **[pure virtual] bool QSGDynamicTexture::updateTexture()**

        Call this function to explicitly update the dynamic texture.

        The function returns true if the texture was changed as a resul of the
        update; otherwise returns false.

        **Note:** This function is typically called from
        **QQuickItem::updatePaintNode** () or **QSGNode::preprocess** (),
        meaning during the `synchronization` or the `node preprocessing` phases
        of the scenegraph. Calling it at other times is discouraged and can lead
        to unexpected behavior.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QWindowStateChangeEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qwindowstatechangeevent.html

    **Detailed Description**
    """

    def clone(self) -> "QWindowStateChangeEvent":
        ...

    def oldState(self) -> QtCore.Qt.WindowState:
        """
        https://doc.qt.io/qt-6/qwindowstatechangeevent.html#oldState

        **Qt::WindowStates QWindowStateChangeEvent::oldState() const**

        Returns the state of the window before the change.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QMdiArea(QAbstractScrollArea):
    """
    https://doc.qt.io/qt-6/qmdiarea.html

    **Detailed Description**

    QMdiArea functions, essentially, like a window manager for MDI windows. For
    instance, it draws the windows it manages on itself and arranges them in a
    cascading or tile pattern. QMdiArea is commonly used as the center widget in
    a **QMainWindow**  to create MDI applications, but can also be placed in any
    layout. The following code adds an area to a main window:

    **QMainWindow**  *mainWindow = new **QMainWindow** ;
    mainWindow->setCentralWidget(mdiArea);

    Unlike the window managers for top-level windows, all window flags
    (**Qt::WindowFlags** ) are supported by QMdiArea as long as the flags are
    supported by the current widget style. If a specific flag is not supported
    by the style (e.g., the **WindowShadeButtonHint** ), you can still shade the
    window with showShaded().

    Subwindows in QMdiArea are instances of **QMdiSubWindow** . They are added
    to an MDI area with **addSubWindow** (). It is common to pass a **QWidget**
    , which is set as the internal widget, to this function, but it is also
    possible to pass a **QMdiSubWindow**  directly. The class inherits
    **QWidget** , and you can use the same API as with a normal top-level window
    when programming. **QMdiSubWindow**  also has behavior that is specific to
    MDI windows. See the **QMdiSubWindow**  class description for more details.

    A subwindow becomes active when it gets the keyboard focus, or when
    **setFocus** () is called. The user activates a window by moving focus in
    the usual ways. The MDI area emits the **subWindowActivated** () signal when
    the active window changes, and the **activeSubWindow** () function returns
    the active subwindow.

    The convenience function **subWindowList** () returns a list of all
    subwindows. This information could be used in a popup menu containing a list
    of windows, for example.

    The subwindows are sorted by the current **WindowOrder** . This is used for
    the **subWindowList** () and for **activateNextSubWindow** () and
    **activatePreviousSubWindow** (). Also, it is used when cascading or tiling
    the windows with **cascadeSubWindows** () and **tileSubWindows** ().

    QMdiArea provides two built-in layout strategies for subwindows:
    **cascadeSubWindows** () and **tileSubWindows** (). Both are slots and are
    easily connected to menu entries.

    ![](images/mdi-cascade.png)![](images/mdi-tile.png)

    **Note:** The default scroll bar property for QMdiArea is
    **Qt::ScrollBarAlwaysOff** .

    **See also** **QMdiSubWindow** .
    """

    class WindowOrder(enum.Enum):
        CreationOrder: QMdiArea = ...
        StackingOrder: QMdiArea = ...
        ActivationHistoryOrder: QMdiArea = ...

    class ViewMode(enum.Enum):
        SubWindowView: QMdiArea = ...
        TabbedView: QMdiArea = ...

    class AreaOption(enum.Flag):
        DontMaximizeSubWindowOnActivation: QMdiArea = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#QMdiArea

        **QMdiArea::QMdiArea(QWidget * parent = nullptr)**

        Constructs an empty mdi area. **parent** is passed to **QWidget** 's
        constructor.
        """
        ...

    def tabsMovable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabsMovable-prop

        **tabsMovable : bool**

        This property holds whether the user can move the tabs within the tabbar
        area in tabbed view mode.

        Tabs are not movable by default.

        **Access functions:**

        bool **tabsMovable** () const
        void **setTabsMovable** (bool
        **movable** )

        **See also** **QTabBar::movable**  and **setViewMode** ().
        """
        ...

    def setTabsMovable(self, movable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabsMovable-prop

        **tabsMovable : bool**

        This property holds whether the user can move the tabs within the tabbar
        area in tabbed view mode.

        Tabs are not movable by default.

        **Access functions:**

        bool **tabsMovable** () const
        void **setTabsMovable** (bool
        **movable** )

        **See also** **QTabBar::movable**  and **setViewMode** ().
        """
        ...

    def tabsClosable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabsClosable-prop

        **tabsClosable : bool**

        This property holds whether the tab bar should place close buttons on
        each tab in tabbed view mode.

        Tabs are not closable by default.

        **Access functions:**

        bool **tabsClosable** () const
        void **setTabsClosable** (bool
        **closable** )

        **See also** **QTabBar::tabsClosable**  and **setViewMode** ().
        """
        ...

    def setTabsClosable(self, closable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabsClosable-prop

        **tabsClosable : bool**

        This property holds whether the tab bar should place close buttons on
        each tab in tabbed view mode.

        Tabs are not closable by default.

        **Access functions:**

        bool **tabsClosable** () const
        void **setTabsClosable** (bool
        **closable** )

        **See also** **QTabBar::tabsClosable**  and **setViewMode** ().
        """
        ...

    def setDocumentMode(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#documentMode-prop

        **documentMode : bool**

        This property holds whether the tab bar is set to document mode in
        tabbed view mode.

        Document mode is disabled by default.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool
        **enabled** )

        **See also** **QTabBar::documentMode**  and **setViewMode** ().
        """
        ...

    def documentMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#documentMode-prop

        **documentMode : bool**

        This property holds whether the tab bar is set to document mode in
        tabbed view mode.

        Document mode is disabled by default.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool
        **enabled** )

        **See also** **QTabBar::documentMode**  and **setViewMode** ().
        """
        ...

    def tabPosition(self) -> "QTabWidget.TabPosition":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabPosition-prop

        **tabPosition : QTabWidget::TabPosition**

        This property holds the position of the tabs in tabbed view mode.

        Possible values for this property are described by the
        **QTabWidget::TabPosition**  enum.

        **Access functions:**

        QTabWidget::TabPosition **tabPosition** () const
        void
        **setTabPosition** (QTabWidget::TabPosition **position** )

        **See also** **QTabWidget::TabPosition**  and **setViewMode** ().
        """
        ...

    def setTabPosition(self, position: "QTabWidget.TabPosition") -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabPosition-prop

        **tabPosition : QTabWidget::TabPosition**

        This property holds the position of the tabs in tabbed view mode.

        Possible values for this property are described by the
        **QTabWidget::TabPosition**  enum.

        **Access functions:**

        QTabWidget::TabPosition **tabPosition** () const
        void
        **setTabPosition** (QTabWidget::TabPosition **position** )

        **See also** **QTabWidget::TabPosition**  and **setViewMode** ().
        """
        ...

    def tabShape(self) -> "QTabWidget.TabShape":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabShape-prop

        **tabShape : QTabWidget::TabShape**

        This property holds the shape of the tabs in tabbed view mode.

        Possible values for this property are **QTabWidget::Rounded**  (default)
        or **QTabWidget::Triangular** .

        **Access functions:**

        QTabWidget::TabShape **tabShape** () const
        void **setTabShape**
        (QTabWidget::TabShape **shape** )

        **See also** **QTabWidget::TabShape**  and **setViewMode** ().
        """
        ...

    def setTabShape(self, shape: "QTabWidget.TabShape") -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tabShape-prop

        **tabShape : QTabWidget::TabShape**

        This property holds the shape of the tabs in tabbed view mode.

        Possible values for this property are **QTabWidget::Rounded**  (default)
        or **QTabWidget::Triangular** .

        **Access functions:**

        QTabWidget::TabShape **tabShape** () const
        void **setTabShape**
        (QTabWidget::TabShape **shape** )

        **See also** **QTabWidget::TabShape**  and **setViewMode** ().
        """
        ...

    def viewMode(self) -> "QMdiArea.ViewMode":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#viewMode-prop

        **viewMode : ViewMode**

        This property holds the way sub-windows are displayed in the
        **QMdiArea** .

        By default, the **SubWindowView**  is used to display sub-windows.

        **Access functions:**

        QMdiArea::ViewMode **viewMode** () const
        void **setViewMode**
        (QMdiArea::ViewMode **mode** )

        **See also** **ViewMode** , **setTabShape** (), and **setTabPosition**
        ().

        **Member Function Documentation**
        """
        ...

    def setViewMode(self, mode: "QMdiArea.ViewMode") -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#viewMode-prop

        **viewMode : ViewMode**

        This property holds the way sub-windows are displayed in the
        **QMdiArea** .

        By default, the **SubWindowView**  is used to display sub-windows.

        **Access functions:**

        QMdiArea::ViewMode **viewMode** () const
        void **setViewMode**
        (QMdiArea::ViewMode **mode** )

        **See also** **ViewMode** , **setTabShape** (), and **setTabPosition**
        ().

        **Member Function Documentation**
        """
        ...

    def setActivationOrder(self, order: "QMdiArea.WindowOrder") -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#activationOrder-prop

        **activationOrder : WindowOrder**

        This property holds the ordering criteria for subwindow lists

        This property specifies the ordering criteria for the list of subwindows
        returned by **subWindowList** (). By default, it is the window creation
        order.

        **Access functions:**

        QMdiArea::WindowOrder **activationOrder** () const
        void
        **setActivationOrder** (QMdiArea::WindowOrder **order** )

        **See also** **subWindowList** ().
        """
        ...

    def activationOrder(self) -> "QMdiArea.WindowOrder":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#activationOrder-prop

        **activationOrder : WindowOrder**

        This property holds the ordering criteria for subwindow lists

        This property specifies the ordering criteria for the list of subwindows
        returned by **subWindowList** (). By default, it is the window creation
        order.

        **Access functions:**

        QMdiArea::WindowOrder **activationOrder** () const
        void
        **setActivationOrder** (QMdiArea::WindowOrder **order** )

        **See also** **subWindowList** ().
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#scrollContentsBy

        **[override virtual protected] void QMdiArea::scrollContentsBy(int dx ,
        int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).
        """
        ...

    def viewportEvent(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#viewportEvent

        **[override virtual protected] bool QMdiArea::viewportEvent(QEvent *
        event )**

        Reimplements: **QAbstractScrollArea::viewportEvent** (QEvent *event).
        """
        ...

    def showEvent(self, showEvent: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#showEvent

        **[override virtual protected] void QMdiArea::showEvent(QShowEvent *
        showEvent )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def timerEvent(self, timerEvent: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#timerEvent

        **[override virtual protected] void QMdiArea::timerEvent(QTimerEvent *
        timerEvent )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def resizeEvent(self, resizeEvent: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#resizeEvent

        **[override virtual protected] void QMdiArea::resizeEvent(QResizeEvent *
        resizeEvent )**

        Reimplements: **QAbstractScrollArea::resizeEvent** (QResizeEvent
        *event).
        """
        ...

    def childEvent(self, childEvent: QtCore.QChildEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#childEvent

        **[override virtual protected] void QMdiArea::childEvent(QChildEvent *
        childEvent )**

        Reimplements: **QObject::childEvent** (QChildEvent *event).
        """
        ...

    def paintEvent(self, paintEvent: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#paintEvent

        **[override virtual protected] void QMdiArea::paintEvent(QPaintEvent *
        paintEvent )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#eventFilter

        **[override virtual protected] bool QMdiArea::eventFilter(QObject *
        object , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#event

        **[override virtual protected] bool QMdiArea::event(QEvent * event )**

        Reimplements: **QAbstractScrollArea::event** (QEvent *event).
        """
        ...

    def setupViewport(self, viewport: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#setupViewport

        **[override virtual protected slot] void QMdiArea::setupViewport(QWidget
        * viewport )**

        Reimplements: **QAbstractScrollArea::setupViewport** (QWidget
        *viewport).

        This slot is called by **QAbstractScrollArea**  after **setViewport** ()
        has been called. Reimplement this function in a subclass of **QMdiArea**
        to initialize the new **viewport** before it is used.

        **See also** **setViewport** ().
        """
        ...

    def activatePreviousSubWindow(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#activatePreviousSubWindow

        **[slot] void QMdiArea::activatePreviousSubWindow()**

        Gives the keyboard focus to another window in the list of child windows.
        The window activated will be the previous one determined by the current
        **activation order** .

        **See also** **activateNextSubWindow** () and **QMdiArea::WindowOrder**
        .
        """
        ...

    def activateNextSubWindow(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#activateNextSubWindow

        **[slot] void QMdiArea::activateNextSubWindow()**

        Gives the keyboard focus to another window in the list of child windows.
        The window activated will be the next one determined by the current
        **activation order** .

        **See also** **activatePreviousSubWindow** () and
        **QMdiArea::WindowOrder** .
        """
        ...

    def closeAllSubWindows(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#closeAllSubWindows

        **[slot] void QMdiArea::closeAllSubWindows()**

        Closes all subwindows by sending a **QCloseEvent**  to each window. You
        may receive **subWindowActivated** () signals from subwindows before
        they are closed (if the MDI area activates the subwindow when another is
        closing).

        Subwindows that ignore the close event will remain open.

        **See also** **closeActiveSubWindow** ().
        """
        ...

    def closeActiveSubWindow(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#closeActiveSubWindow

        **[slot] void QMdiArea::closeActiveSubWindow()**

        Closes the active subwindow.

        **See also** **closeAllSubWindows** ().
        """
        ...

    def cascadeSubWindows(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#cascadeSubWindows

        **[slot] void QMdiArea::cascadeSubWindows()**

        Arranges all the child windows in a cascade pattern.

        **See also** **tileSubWindows** ().
        """
        ...

    def tileSubWindows(self) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#tileSubWindows

        **[slot] void QMdiArea::tileSubWindows()**

        Arranges all child windows in a tile pattern.

        **See also** **cascadeSubWindows** ().
        """
        ...

    def setActiveSubWindow(self, window: "QMdiSubWindow") -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#setActiveSubWindow

        **[slot] void QMdiArea::setActiveSubWindow(QMdiSubWindow * window )**

        Activates the subwindow **window**. If **window** is `nullptr`, any
        current active window is deactivated.

        **See also** **activeSubWindow** ().
        """
        ...

    def testOption(self, opton: "QMdiArea.AreaOption") -> bool:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#testOption

        **bool QMdiArea::testOption(QMdiArea::AreaOption option ) const**

        Returns `true` if **option** is enabled; otherwise returns `false`.

        **See also** **AreaOption**  and **setOption** ().
        """
        ...

    def setOption(self, option: "QMdiArea.AreaOption", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#setOption

        **void QMdiArea::setOption(QMdiArea::AreaOption option , bool on =
        true)**

        If **on** is true, **option** is enabled on the MDI area; otherwise it
        is disabled. See **AreaOption**  for the effect of each option.

        **See also** **AreaOption**  and **testOption** ().
        """
        ...

    def setBackground(
        self,
        background: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#background-prop

        **background : QBrush**

        This property holds the background brush for the workspace

        This property sets the background brush for the workspace area itself.
        By default, it is a gray color, but can be any brush (e.g., colors,
        gradients or pixmaps).

        **Access functions:**

        QBrush **background** () const
        void **setBackground** (const QBrush &
        **background** )
        """
        ...

    def background(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#background-prop

        **background : QBrush**

        This property holds the background brush for the workspace

        This property sets the background brush for the workspace area itself.
        By default, it is a gray color, but can be any brush (e.g., colors,
        gradients or pixmaps).

        **Access functions:**

        QBrush **background** () const
        void **setBackground** (const QBrush &
        **background** )
        """
        ...

    def removeSubWindow(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#removeSubWindow

        **void QMdiArea::removeSubWindow(QWidget * widget )**

        Removes **widget** from the MDI area. The **widget** must be either a
        **QMdiSubWindow**  or a widget that is the internal widget of a
        subwindow. Note **widget** is never actually deleted by **QMdiArea** .
        If a **QMdiSubWindow**  is passed in, its parent is set to `nullptr` and
        it is removed; but if an internal widget is passed in, the child widget
        is set to `nullptr` and the **QMdiSubWindow**  is **not** removed.

        **See also** **addSubWindow** ().
        """
        ...

    def currentSubWindow(self) -> "QMdiSubWindow":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#currentSubWindow

        **QMdiSubWindow *QMdiArea::currentSubWindow() const**

        Returns a pointer to the current subwindow, or `nullptr` if there is no
        current subwindow.

        This function will return the same as **activeSubWindow** () if the
        **QApplication**  containing **QMdiArea**  is active.

        **See also** **activeSubWindow** () and **QApplication::activeWindow**
        ().
        """
        ...

    def subWindowList(
        self, order: "QMdiArea.WindowOrder" = ...
    ) -> typing.List["QMdiSubWindow"]:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#subWindowList

        **QList<QMdiSubWindow *> QMdiArea::subWindowList(QMdiArea::WindowOrder
        order = CreationOrder) const**

        Returns a list of all subwindows in the MDI area. If **order** is
        **CreationOrder**  (the default), the windows are sorted in the order in
        which they were inserted into the workspace. If **order** is
        **StackingOrder** , the windows are listed in their stacking order, with
        the topmost window as the last item in the list. If **order** is
        **ActivationHistoryOrder** , the windows are listed according to their
        recent activation history.

        **See also** **WindowOrder** .
        """
        ...

    def addSubWindow(
        self, widget: QWidget, flags: QtCore.Qt.WindowType = ...
    ) -> "QMdiSubWindow":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#addSubWindow

        **QMdiSubWindow *QMdiArea::addSubWindow(QWidget * widget ,
        Qt::WindowFlags windowFlags = Qt::WindowFlags())**

        Adds **widget** as a new subwindow to the MDI area. If **windowFlags**
        are non-zero, they will override the flags set on the widget.

        The **widget** can be either a **QMdiSubWindow**  or another **QWidget**
        (in which case the MDI area will create a subwindow and set the
        **widget** as the internal widget).

        **Note:** Once the subwindow has been added, its parent will be the
        **viewport widget** of the **QMdiArea** .

        **QMdiArea**  mdiArea;
                **QMdiSubWindow**  *subWindow1 = new
        **QMdiSubWindow** ;
                subWindow1->setWidget(internalWidget1);
        subWindow1->setAttribute(Qt::WA_DeleteOnClose);
        mdiArea.addSubWindow(subWindow1);

                **QMdiSubWindow**
        *subWindow2 =
                    mdiArea.addSubWindow(internalWidget2);

        When you create your own subwindow, you must set the
        **Qt::WA_DeleteOnClose**  widget attribute if you want the window to be
        deleted when closed in the MDI area. If not, the window will be hidden
        and the MDI area will not activate the next subwindow.

        Returns the **QMdiSubWindow**  that is added to the MDI area.

        **See also** **removeSubWindow** ().
        """
        ...

    def activeSubWindow(self) -> "QMdiSubWindow":
        """
        https://doc.qt.io/qt-6/qmdiarea.html#activeSubWindow

        **QMdiSubWindow *QMdiArea::activeSubWindow() const**

        Returns a pointer to the current active subwindow. If no window is
        currently active, `nullptr` is returned.

        Subwindows are treated as top-level windows with respect to window
        state, i.e., if a widget outside the MDI area is the active window, no
        subwindow will be active. Note that if a widget in the window in which
        the MDI area lives gains focus, the window will be activated.

        **See also** **setActiveSubWindow** () and **Qt::WindowState** .
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#minimumSizeHint

        **[override virtual] QSize QMdiArea::minimumSizeHint() const**

        Reimplements: **QAbstractScrollArea::minimumSizeHint() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#sizeHint

        **[override virtual] QSize QMdiArea::sizeHint() const**

        Reimplements: **QAbstractScrollArea::sizeHint() const** .
        """
        ...

    @property
    def subWindowActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmdiarea.html#subWindowActivated

        **[signal] void QMdiArea::subWindowActivated(QMdiSubWindow * window )**

        **QMdiArea**  emits this signal after **window** has been activated.
        When **window** is `nullptr`, **QMdiArea**  has just deactivated its
        last active window, and there are no active windows on the workspace.

        **See also** **QMdiArea::activeSubWindow** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QWinEventNotifier(QObject):
    """
    https://doc.qt.io/qt-6/qwineventnotifier.html

    **Detailed Description**

    The QWinEventNotifier class makes it possible to use the wait functions on
    windows in a asynchronous manner. With this class, you can register a HANDLE
    to an event and get notification when that event becomes signalled. The
    state of the event is not modified in the process so if it is a manual reset
    event you will need to reset it after the notification.

    Once you have created a event object using Windows API such as CreateEvent()
    or OpenEvent(), you can create an event notifier to monitor the event
    handle. If the event notifier is enabled, it will emit the **activated** ()
    signal whenever the corresponding event object is signalled.

    The **setEnabled** () function allows you to disable as well as enable the
    event notifier. It is generally advisable to explicitly enable or disable
    the event notifier. A disabled notifier does nothing when the event object
    is signalled (the same effect as not creating the event notifier). Use the
    **isEnabled** () function to determine the notifier's current status.

    Finally, you can use the **setHandle** () function to register a new event
    object, and the **handle** () function to retrieve the event handle.

    **Further information:** Although the class is called QWinEventNotifier, it
    can be used for certain other objects which are so-called synchronization
    objects, such as Processes, Threads, Waitable timers.

    **Warning:** This class is only available on Windows.
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#QWinEventNotifier

        **QWinEventNotifier::QWinEventNotifier(QObject * parent = nullptr)**

        Constructs an event notifier with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, hEvent: PyQt6.sip.voidptr, parent: typing.Optional[QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#QWinEventNotifier-1

        **QWinEventNotifier::QWinEventNotifier(QWinEventNotifier::HANDLE hEvent
        , QObject * parent = nullptr)**

        Constructs an event notifier with the given **parent**. It enables the
        notifier, and watches for the event **hEvent**.

        The notifier is enabled by default, i.e. it emits the **activated** ()
        signal whenever the corresponding event is signalled. However, it is
        generally advisable to explicitly enable or disable the event notifier.

        **See also** **setEnabled** () and **isEnabled** ().
        """
        ...

    def event(self, e: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#event

        **[override virtual protected] bool QWinEventNotifier::event(QEvent * e
        )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def setEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#setEnabled

        **[slot] void QWinEventNotifier::setEnabled(bool enable )**

        If **enable** is true, the notifier is enabled; otherwise the notifier
        is disabled.

        **See also** **isEnabled** () and **activated** ().
        """
        ...

    def setHandle(self, hEvent: PyQt6.sip.voidptr) -> None:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#setHandle

        **void QWinEventNotifier::setHandle(QWinEventNotifier::HANDLE hEvent )**

        Register the HANDLE **hEvent**. The old HANDLE will be automatically
        unregistered.

        **Note** : The notifier will be disabled as a side effect and needs to
        be re-enabled.

        **See also** **handle** () and **setEnabled** ().
        """
        ...

    def isEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#isEnabled

        **bool QWinEventNotifier::isEnabled() const**

        Returns `true` if the notifier is enabled; otherwise returns `false`.

        **See also** **setEnabled** ().
        """
        ...

    def handle(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#handle

        **QWinEventNotifier::HANDLE QWinEventNotifier::handle() const**

        Returns the HANDLE that has been registered in the notifier.

        **See also** **setHandle** ().
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwineventnotifier.html#activated

        **[private signal] void
        QWinEventNotifier::activated(QWinEventNotifier::HANDLE hEvent )**

        This signal is emitted whenever the event notifier is enabled and the
        corresponding HANDLE is signalled.

        The state of the event is not modified in the process, so if it is a
        manual reset event, you will need to reset it after the notification.

        The object is passed in the **hEvent** parameter.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **handle** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QLocalSocket(QtCore.QIODevice):
    """
    https://doc.qt.io/qt-6/qlocalsocket.html

    **Detailed Description**

    On Windows this is a named pipe and on Unix this is a local domain socket.

    If an error occurs, **error** () returns the type of error, and
    **errorString** () can be called to get a human readable description of what
    happened.

    Although QLocalSocket is designed for use with an event loop, it's possible
    to use it without one. In that case, you must use **waitForConnected** (),
    **waitForReadyRead** (), **waitForBytesWritten** (), and
    **waitForDisconnected** () which blocks until the operation is complete or
    the timeout expires.

    **See also** **QLocalServer** .
    """

    class SocketOption(enum.Flag):
        NoOptions: QLocalSocket = ...
        AbstractNamespaceOption: QLocalSocket = ...

    class LocalSocketState(enum.Enum):
        UnconnectedState: QLocalSocket = ...
        ConnectingState: QLocalSocket = ...
        ConnectedState: QLocalSocket = ...
        ClosingState: QLocalSocket = ...

    class LocalSocketError(enum.Enum):
        ConnectionRefusedError: QLocalSocket = ...
        PeerClosedError: QLocalSocket = ...
        ServerNotFoundError: QLocalSocket = ...
        SocketAccessError: QLocalSocket = ...
        SocketResourceError: QLocalSocket = ...
        SocketTimeoutError: QLocalSocket = ...
        DatagramTooLargeError: QLocalSocket = ...
        ConnectionError: QLocalSocket = ...
        UnsupportedSocketOperationError: QLocalSocket = ...
        OperationError: QLocalSocket = ...
        UnknownSocketError: QLocalSocket = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#QLocalSocket

        **QLocalSocket::QLocalSocket(QObject * parent = nullptr)**

        Creates a new local socket. The **parent** argument is passed to
        **QObject** 's constructor.
        """
        ...

    def socketOptions(self) -> "QLocalSocket.SocketOption":
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#socketOptions-prop

        **[bindable, since 6.2] socketOptions : SocketOptions**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the socket options.

        Options must be set while the socket is in **UnconnectedState**  state.

        This property was introduced in Qt 6.2.

        **See also** **connectToServer** ().

        **Member Function Documentation**
        """
        ...

    def setSocketOptions(self, option: "QLocalSocket.SocketOption") -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#socketOptions-prop

        **[bindable, since 6.2] socketOptions : SocketOptions**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the socket options.

        Options must be set while the socket is in **UnconnectedState**  state.

        This property was introduced in Qt 6.2.

        **See also** **connectToServer** ().

        **Member Function Documentation**
        """
        ...

    def skipData(self, maxSize: int) -> int:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#skipData

        **[override virtual protected] qint64 QLocalSocket::skipData(qint64
        maxSize )**

        Reimplements: **QIODevice::skipData** (qint64 maxSize).
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#writeData

        **[override virtual protected] qint64 QLocalSocket::writeData(const char
        * data , qint64 c )**

        Reimplements: **QIODevice::writeData** (const char *data, qint64
        maxSize).
        """
        ...

    def readData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#readData

        **[override virtual protected] qint64 QLocalSocket::readData(char * data
        , qint64 c )**

        Reimplements: **QIODevice::readData** (char *data, qint64 maxSize).
        """
        ...

    def waitForReadyRead(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#waitForReadyRead

        **[override virtual] bool QLocalSocket::waitForReadyRead(int msecs =
        30000)**

        Reimplements: **QIODevice::waitForReadyRead** (int msecs).

        This function blocks until data is available for reading and the
        **readyRead** () signal has been emitted. The function will timeout
        after **msecs** milliseconds; the default timeout is 30000 milliseconds.

        The function returns `true` if data is available for reading; otherwise
        it returns `false` (if an error occurred or the operation timed out).

        **See also** **waitForBytesWritten** ().
        """
        ...

    def waitForDisconnected(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#waitForDisconnected

        **bool QLocalSocket::waitForDisconnected(int msecs = 30000)**

        Waits until the socket has disconnected, up to **msecs** milliseconds.
        If the connection was successfully disconnected, this function returns
        `true`; otherwise it returns `false` (if the operation timed out, if an
        error occurred, or if this **QLocalSocket**  is already disconnected).
        In the case where it returns `false`, you can call **error** () to
        determine the cause of the error.

        The following example waits up to one second for a connection to be
        closed:

        socket->disconnectFromServer();
            if (socket->state() ==
        **QLocalSocket** ::UnconnectedState
                ||
        socket->waitForDisconnected(1000)) {
                **qDebug**
        ("Disconnected!");
            }

        If **msecs** is -1, this function will not time out.

        **See also** **disconnectFromServer** () and **close** ().
        """
        ...

    def waitForConnected(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#waitForConnected

        **bool QLocalSocket::waitForConnected(int msecs = 30000)**

        Waits until the socket is connected, up to **msecs** milliseconds. If
        the connection has been established, this function returns `true`;
        otherwise it returns `false`. In the case where it returns `false`, you
        can call **error** () to determine the cause of the error.

        The following example waits up to one second for a connection to be
        established:

        socket->connectToServer("market");
            if
        (socket->waitForConnected(1000))
                **qDebug** ("Connected!");

        If **msecs** is -1, this function will not time out.

        **See also** **connectToServer** () and **connected** ().
        """
        ...

    def waitForBytesWritten(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#waitForBytesWritten

        **[override virtual] bool QLocalSocket::waitForBytesWritten(int msecs =
        30000)**

        Reimplements: **QIODevice::waitForBytesWritten** (int msecs).
        """
        ...

    def state(self) -> "QLocalSocket.LocalSocketState":
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#state

        **QLocalSocket::LocalSocketState QLocalSocket::state() const**

        Returns the state of the socket.

        **See also** **error** ().
        """
        ...

    def socketDescriptor(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#socketDescriptor

        **qintptr QLocalSocket::socketDescriptor() const**

        Returns the native socket descriptor of the **QLocalSocket**  object if
        this is available; otherwise returns -1.

        The socket descriptor is not available when **QLocalSocket**  is in
        **UnconnectedState** . The type of the descriptor depends on the
        platform:

        * On Windows, the returned value is a **Winsock 2 Socket Handle** .
          *
        On INTEGRITY, the returned value is the **QTcpSocket**  socket
        descriptor and the type is defined by **socketDescriptor** .
          * On all
        other UNIX-like operating systems, the type is a file descriptor
        representing a socket.

        **See also** **setSocketDescriptor** ().
        """
        ...

    def setSocketDescriptor(
        self,
        socketDescriptor: PyQt6.sip.voidptr,
        state: "QLocalSocket.LocalSocketState" = ...,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#setSocketDescriptor

        **bool QLocalSocket::setSocketDescriptor(qintptr socketDescriptor ,
        QLocalSocket::LocalSocketState socketState = ConnectedState,
        QIODeviceBase::OpenMode openMode = ReadWrite)**

        Initializes **QLocalSocket**  with the native socket descriptor
        **socketDescriptor**. Returns `true` if **socketDescriptor**  is
        accepted as a valid socket descriptor; otherwise returns `false`. The
        socket is opened in the mode specified by **openMode** , and enters the
        socket state specified by **socketState**.

        **Note:** It is not possible to initialize two local sockets with the
        same native socket descriptor.

        **See also** **socketDescriptor** (), **state** (), and **openMode** ().
        """
        ...

    def setReadBufferSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#setReadBufferSize

        **void QLocalSocket::setReadBufferSize(qint64 size )**

        Sets the size of **QLocalSocket** 's internal read buffer to be **size**
        bytes.

        If the buffer size is limited to a certain size, **QLocalSocket**  won't
        buffer more than this size of data. Exceptionally, a buffer size of 0
        means that the read buffer is unlimited and all incoming data is
        buffered. This is the default.

        This option is useful if you only read the data at certain points in
        time (e.g., in a real-time streaming application) or if you want to
        protect your socket against receiving too much data, which may
        eventually cause your application to run out of memory.

        **See also** **readBufferSize** () and **read** ().
        """
        ...

    def readBufferSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#readBufferSize

        **qint64 QLocalSocket::readBufferSize() const**

        Returns the size of the internal read buffer. This limits the amount of
        data that the client can receive before you call **read** () or
        **readAll** (). A read buffer size of 0 (the default) means that the
        buffer has no size limit, ensuring that no data is lost.

        **See also** **setReadBufferSize** () and **read** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#isValid

        **bool QLocalSocket::isValid() const**

        Returns `true` if the socket is valid and ready for use; otherwise
        returns `false`.

        **Note:** The socket's state must be **ConnectedState**  before reading
        and writing can occur.

        **See also** **state** () and **connectToServer** ().
        """
        ...

    def flush(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#flush

        **bool QLocalSocket::flush()**

        This function writes as much as possible from the internal write buffer
        to the socket, without blocking. If any data was written, this function
        returns `true`; otherwise false is returned.

        Call this function if you need **QLocalSocket**  to start sending
        buffered data immediately. The number of bytes successfully written
        depends on the operating system. In most cases, you do not need to call
        this function, because **QLocalSocket**  will start sending data
        automatically once control goes back to the event loop. In the absence
        of an event loop, call **waitForBytesWritten** () instead.

        **See also** **write** () and **waitForBytesWritten** ().
        """
        ...

    def error(self) -> "QLocalSocket.LocalSocketError":
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#error

        **QLocalSocket::LocalSocketError QLocalSocket::error() const**

        Returns the type of error that last occurred.

        **See also** **state** () and **errorString** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#close

        **[override virtual] void QLocalSocket::close()**

        Reimplements: **QIODevice::close** ().
        """
        ...

    def canReadLine(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#canReadLine

        **[override virtual] bool QLocalSocket::canReadLine() const**

        Reimplements: **QIODevice::canReadLine() const** .
        """
        ...

    def bytesToWrite(self) -> int:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#bytesToWrite

        **[override virtual] qint64 QLocalSocket::bytesToWrite() const**

        Reimplements: **QIODevice::bytesToWrite() const** .
        """
        ...

    def bytesAvailable(self) -> int:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#bytesAvailable

        **[override virtual] qint64 QLocalSocket::bytesAvailable() const**

        Reimplements: **QIODevice::bytesAvailable() const** .
        """
        ...

    def isSequential(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#isSequential

        **[override virtual] bool QLocalSocket::isSequential() const**

        Reimplements: **QIODevice::isSequential() const** .
        """
        ...

    def abort(self) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#abort

        **void QLocalSocket::abort()**

        Aborts the current connection and resets the socket. Unlike
        **disconnectFromServer** (), this function immediately closes the
        socket, clearing any pending data in the write buffer.

        **See also** **disconnectFromServer** () and **close** ().
        """
        ...

    def fullServerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#fullServerName

        **QString QLocalSocket::fullServerName() const**

        Returns the server path that the socket is connected to.

        **Note:** The return value of this function is platform specific.

        **See also** **connectToServer** () and **serverName** ().
        """
        ...

    def setServerName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#setServerName

        **[since 5.1] void QLocalSocket::setServerName(const QString & name )**

        Set the **name** of the peer to connect to. On Windows name is the name
        of a named pipe; on Unix name is the name of a local domain socket.

        This function must be called when the socket is not connected.

        This function was introduced in Qt 5.1.

        **See also** **serverName** ().
        """
        ...

    def serverName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#serverName

        **QString QLocalSocket::serverName() const**

        Returns the name of the peer as specified by **setServerName** (), or an
        empty **QString**  if **setServerName** () has not been called or
        **connectToServer** () failed.

        **See also** **setServerName** (), **connectToServer** (), and
        **fullServerName** ().
        """
        ...

    def open(self, mode: QtCore.QIODeviceBase.OpenModeFlag = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#open

        **[override virtual] bool QLocalSocket::open(QIODeviceBase::OpenMode
        openMode = ReadWrite)**

        Reimplements: **QIODevice::open** (QIODeviceBase::OpenMode mode).

        Equivalent to **connectToServer** (OpenMode mode). The socket is opened
        in the given **openMode** to the server defined by **setServerName** ().

        Note that unlike in most other **QIODevice**  subclasses, open() may not
        open the device directly. The function return false if the socket was
        already connected or if the server to connect to was not defined and
        true in any other case. The **connected** () or **errorOccurred** ()
        signals will be emitted once the device is actually open (or the
        connection failed).

        See **connectToServer** () for more details.
        """
        ...

    def disconnectFromServer(self) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#disconnectFromServer

        **void QLocalSocket::disconnectFromServer()**

        Attempts to close the socket. If there is pending data waiting to be
        written, **QLocalSocket**  will enter **ClosingState**  and wait until
        all data has been written. Eventually, it will enter
        **UnconnectedState**  and emit the **disconnected** () signal.

        **See also** **connectToServer** ().
        """
        ...

    @typing.overload
    def connectToServer(
        self, name: str, mode: QtCore.QIODeviceBase.OpenModeFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#connectToServer

        **[since 5.1] void QLocalSocket::connectToServer(QIODeviceBase::OpenMode
        openMode = ReadWrite)**

        Attempts to make a connection to **serverName** (). **setServerName** ()
        must be called before you open the connection. Alternatively you can use
        connectToServer(const **QString**  &name, OpenMode openMode);

        The socket is opened in the given **openMode** and first enters
        **ConnectingState** . If a connection is established, **QLocalSocket**
        enters **ConnectedState**  and emits **connected** ().

        After calling this function, the socket can emit **errorOccurred** () to
        signal that an error occurred.

        This function was introduced in Qt 5.1.

        **See also** **state** (), **serverName** (), and **waitForConnected**
        ().
        """
        ...

    @typing.overload
    def connectToServer(self, mode: QtCore.QIODeviceBase.OpenModeFlag = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#connectToServer-1

        **void QLocalSocket::connectToServer(const QString & name ,
        QIODeviceBase::OpenMode openMode = ReadWrite)**

        This is an overloaded function.

        Set the server **name** and attempts to make a connection to it.

        The socket is opened in the given **openMode** and first enters
        **ConnectingState** . If a connection is established, **QLocalSocket**
        enters **ConnectedState**  and emits **connected** ().

        After calling this function, the socket can emit **errorOccurred** () to
        signal that an error occurred.

        **See also** **state** (), **serverName** (), and **waitForConnected**
        ().
        """
        ...

    @property
    def connected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#connected

        **[signal] void QLocalSocket::connected()**

        This signal is emitted after **connectToServer** () has been called and
        a connection has been successfully established.

        **See also** **connectToServer** () and **disconnected** ().
        """
        ...

    @property
    def disconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#disconnected

        **[signal] void QLocalSocket::disconnected()**

        This signal is emitted when the socket has been disconnected.

        **See also** **connectToServer** (), **disconnectFromServer** (),
        **abort** (), and **connected** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#errorOccurred

        **[signal, since 5.15] void
        QLocalSocket::errorOccurred(QLocalSocket::LocalSocketError socketError
        )**

        This signal is emitted after an error occurred. The **socketError**
        parameter describes the type of error that occurred.

        **QLocalSocket::LocalSocketError**  is not a registered metatype, so for
        queued connections, you will have to register it with
        **Q_DECLARE_METATYPE** () and **qRegisterMetaType** ().

        This function was introduced in Qt 5.15.

        **See also** **error** (), **errorString** (), and **Creating Custom Qt
        Types** .
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlocalsocket.html#stateChanged

        **[signal] void
        QLocalSocket::stateChanged(QLocalSocket::LocalSocketState socketState
        )**

        This signal is emitted whenever **QLocalSocket** 's state changes. The
        **socketState** parameter is the new state.

        QLocalSocket::SocketState is not a registered metatype, so for queued
        connections, you will have to register it with **Q_DECLARE_METATYPE** ()
        and **qRegisterMetaType** ().

        **See also** **state** () and **Creating Custom Qt Types** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QCompressedHelpInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcompressedhelpinfo.html

    **Detailed Description**

    The detailed information about the compressed help file can be fetched by
    calling the **fromCompressedHelpFile** () static method, providing the path
    to the compressed help file.

    The class provides access to various information about a compressed help
    file. The namespace associated with the given compressed help file is
    **namespaceName** (), the associated component name is **component** () and
    **version** () provides version information.

    **See also** **QHelpFilterEngine** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#QCompressedHelpInfo

        **QCompressedHelpInfo::QCompressedHelpInfo()**

        Constructs empty information about a compressed help file.
        """
        ...

    @typing.overload
    def __init__(self, other: "QCompressedHelpInfo") -> None:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#QCompressedHelpInfo-1

        **QCompressedHelpInfo::QCompressedHelpInfo(const QCompressedHelpInfo &
        other )**

        Constructs a copy of **other**.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#isNull

        **bool QCompressedHelpInfo::isNull() const**

        Returns `true` if the info is invalid, otherwise returns `false`.
        """
        ...

    @staticmethod
    def fromCompressedHelpFile(documentationFileName: str) -> "QCompressedHelpInfo":
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#fromCompressedHelpFile

        **[static] QCompressedHelpInfo
        QCompressedHelpInfo::fromCompressedHelpFile(const QString &
        documentationFileName )**

        Returns the **QCompressedHelpInfo**  instance for the
        **documentationFileName** of the existing qch file.
        """
        ...

    def version(self) -> QtCore.QVersionNumber:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#version

        **QVersionNumber QCompressedHelpInfo::version() const**

        Returns the version of the compressed help file.
        """
        ...

    def component(self) -> str:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#component

        **QString QCompressedHelpInfo::component() const**

        Returns the component of the compressed help file.
        """
        ...

    def namespaceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#namespaceName

        **QString QCompressedHelpInfo::namespaceName() const**

        Returns the namespace name of the compressed help file.
        """
        ...

    def swap(self, other: "QCompressedHelpInfo") -> None:
        """
        https://doc.qt.io/qt-6/qcompressedhelpinfo.html#swap

        **void QCompressedHelpInfo::swap(QCompressedHelpInfo & other )**

        Swaps the compressed help file **other** with this compressed help file.
        This operation is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtDBus import *


class QDBusReply(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusreply.html

    **Detailed Description**

    A QDBusReply object is a subset of the **QDBusMessage**  object that
    represents a method call's reply. It contains only the first output argument
    or the error code and is used by **QDBusInterface** -derived classes to
    allow returning the error code as the function's return argument.

    It can be used in the following manner:

    **QDBusReply** <**QString** > reply = interface->call("RemoteMethod");
    if (reply.isValid())
            // use the returned value
    useValue(reply.value());
        else
            // call failed. Show an error
    condition.
            showError(reply.error());

    If the remote method call cannot fail, you can skip the error checking:

    reply = interface->call("RemoteMethod");

    However, if it does fail under those conditions, the value returned by
    QDBusReply<T>::value() is a default-constructed value. It may be
    indistinguishable from a valid return value.

    QDBusReply objects are used for remote calls that have no output arguments
    or return values (i.e., they have a "void" return type). Use the **isValid**
    () function to test if the reply succeeded.

    **See also** **QDBusMessage**  and **QDBusInterface** .
    """

    @typing.overload
    def __init__(self, reply: QDBusMessage) -> None:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#QDBusReply

        **QDBusReply::QDBusReply(const QDBusMessage & reply )**

        Automatically construct a QDBusReply object from the reply message
        **reply** , extracting the first return value from it if it is a success
        reply.
        """
        ...

    @typing.overload
    def __init__(self, call: QDBusPendingCall) -> None:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#QDBusReply-1

        **[since 5.15] QDBusReply::QDBusReply(const QDBusReply<T> & other )**

        Constructs a copy of **other**.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def __init__(self, error: QDBusError) -> None:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#QDBusReply-2

        **QDBusReply::QDBusReply(const QDBusPendingCall & pcall )**

        Automatically construct a QDBusReply object from the asynchronous
        pending call **pcall**. If the call isn't finished yet, QDBusReply will
        call QDBusPendingCall::waitForFinished(), which is a blocking operation.

        If the return types patch, QDBusReply will extract the first return
        argument from the reply.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDBusReply") -> None:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#QDBusReply-3

        **QDBusReply::QDBusReply(const QDBusPendingReply<T> & reply )**

        Constructs a QDBusReply object from the pending reply message,
        **reply**.
        """
        ...

    def value(self, type: typing.Any = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#value

        **QDBusReply::Type QDBusReply::value() const**

        Returns the remote function's calls return value. If the remote call
        returned with an error, the return value of this function is undefined
        and may be undistinguishable from a valid return value.

        This function is not available if the remote call returns `void`.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#isValid

        **bool QDBusReply::isValid() const**

        Returns `true` if no error occurred; otherwise, returns `false`.

        **See also** **error** ().
        """
        ...

    def error(self) -> QDBusError:
        """
        https://doc.qt.io/qt-6/qdbusreply.html#error

        **const QDBusError &QDBusReply::error() const**

        Returns the error code that was returned from the remote function call.
        If the remote call did not return an error (i.e., if it succeeded), then
        the **QDBusError**  object that is returned will not be a valid error
        code (**QDBusError::isValid** () will return false).

        **See also** **isValid** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMediaTimeRange(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmediatimerange.html

    **Detailed Description**

    The **earliestTime** (), **latestTime** (), **intervals** () and **isEmpty**
    () methods are used to get information about the current time range.

    The **addInterval** (), **removeInterval** () and **clear** () methods are
    used to modify the current time range.

    When adding or removing intervals from the time range, existing intervals
    within the range may be expanded, trimmed, deleted, merged or split to
    ensure that all intervals within the time range remain distinct and
    disjoint. As a consequence, all intervals added or removed from a time range
    must be **normal** .

    **See also** **QMediaTimeRange::Interval** .
    """

    class Interval(PyQt6.sip.simplewrapper):
        @typing.overload
        def __init__(self, start: int, end: int) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QMediaTimeRange.Interval") -> None:
            ...

        def translated(self, offset: int) -> "QMediaTimeRange.Interval":
            ...

        def normalized(self) -> "QMediaTimeRange.Interval":
            ...

        def isNormal(self) -> bool:
            ...

        def contains(self, time: int) -> bool:
            ...

        def end(self) -> int:
            ...

        def start(self) -> int:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#QMediaTimeRange

        **QMediaTimeRange::QMediaTimeRange()**

        Constructs an empty time range.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QMediaTimeRange.Interval") -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#QMediaTimeRange-1

        **QMediaTimeRange::QMediaTimeRange(qint64 start , qint64 end )**

        Constructs a time range that contains an initial interval from **start**
        to **end** inclusive.

        If the interval is not **normal** , the resulting time range will be
        empty.

        **See also** **addInterval** ().
        """
        ...

    @typing.overload
    def __init__(self, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#QMediaTimeRange-2

        **QMediaTimeRange::QMediaTimeRange(const QMediaTimeRange::Interval &
        interval )**

        Constructs a time range that contains an initial interval, **interval**.

        If **interval** is not **normal** , the resulting time range will be
        empty.

        **See also** **addInterval** ().
        """
        ...

    @typing.overload
    def __init__(self, range: "QMediaTimeRange") -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#QMediaTimeRange-3

        **QMediaTimeRange::QMediaTimeRange(const QMediaTimeRange & range )**

        Constructs a time range by copying another time **range**.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#clear

        **void QMediaTimeRange::clear()**

        Removes all intervals from the time range.

        **See also** **removeInterval** ().
        """
        ...

    def removeTimeRange(self, a0: "QMediaTimeRange") -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#removeTimeRange

        **void QMediaTimeRange::removeTimeRange(const QMediaTimeRange & range
        )**

        Removes each of the intervals in **range** from this time range.

        Equivalent to calling **removeInterval** () for each interval in
        **range**.
        """
        ...

    @typing.overload
    def removeInterval(self, interval: "QMediaTimeRange.Interval") -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#removeInterval

        **void QMediaTimeRange::removeInterval(const QMediaTimeRange::Interval &
        interval )**

        Removes the specified **interval** from the time range.

        Removing intervals which are not **normal**  is invalid, and will be
        ignored.

        Intervals within the time range will be trimmed, split or deleted such
        that no intervals within the time range include any part of the target
        interval.

        This operation takes linear time.

        **See also** **addInterval** ().
        """
        ...

    @typing.overload
    def removeInterval(self, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#removeInterval-1

        **void QMediaTimeRange::removeInterval(qint64 start , qint64 end )**

        This is an overloaded function.

        Removes the interval specified by **start** and **end** from the time
        range.

        **See also** **removeInterval** ().
        """
        ...

    def addTimeRange(self, a0: "QMediaTimeRange") -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#addTimeRange

        **void QMediaTimeRange::addTimeRange(const QMediaTimeRange & range )**

        Adds each of the intervals in **range** to this time range.

        Equivalent to calling **addInterval** () for each interval in **range**.
        """
        ...

    @typing.overload
    def addInterval(self, interval: "QMediaTimeRange.Interval") -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#addInterval

        **void QMediaTimeRange::addInterval(const QMediaTimeRange::Interval &
        interval )**

        Adds the specified **interval** to the time range.

        Adding intervals which are not **normal**  is invalid, and will be
        ignored.

        If the specified interval is adjacent to, or overlaps existing intervals
        within the time range, these intervals will be merged.

        This operation takes linear time.

        **See also** **removeInterval** ().
        """
        ...

    @typing.overload
    def addInterval(self, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#addInterval-1

        **void QMediaTimeRange::addInterval(qint64 start , qint64 end )**

        This is an overloaded function.

        Adds the interval specified by **start** and **end** to the time range.

        **See also** **addInterval** ().
        """
        ...

    def contains(self, time: int) -> bool:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#contains

        **bool QMediaTimeRange::contains(qint64 time ) const**

        Returns true if the specified **time** lies within the time range.
        """
        ...

    def isContinuous(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#isContinuous

        **bool QMediaTimeRange::isContinuous() const**

        Returns true if the time range consists of a continuous interval. That
        is, there is one or fewer disjoint intervals within the time range.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#isEmpty

        **bool QMediaTimeRange::isEmpty() const**

        Returns true if there are no intervals within the time range.

        **See also** **intervals** ().
        """
        ...

    def intervals(self) -> typing.List["QMediaTimeRange.Interval"]:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#intervals

        **QList<QMediaTimeRange::Interval> QMediaTimeRange::intervals() const**

        Returns the list of intervals covered by this time range.
        """
        ...

    def latestTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#latestTime

        **qint64 QMediaTimeRange::latestTime() const**

        Returns the latest time within the time range.

        For empty time ranges, this value is equal to zero.

        **See also** **earliestTime** ().
        """
        ...

    def earliestTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediatimerange.html#earliestTime

        **qint64 QMediaTimeRange::earliestTime() const**

        Returns the earliest time within the time range.

        For empty time ranges, this value is equal to zero.

        **See also** **latestTime** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QProximityReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qproximityreading.html

    **Detailed Description**

    The proximity sensor can only indicate if an object is close or not.

    The distance at which an object is considered close is device-specific. This
    distance may be available in the **QSensor::outputRanges**  property.
    """

    def setClose(self, close: bool) -> None:
        """
        https://doc.qt.io/qt-6/qproximityreading.html#setClose

        **void QProximityReading::setClose(bool close )**

        Sets the close value to **close**.

        **See also** **close** ().
        """
        ...

    def close(self) -> bool:
        """
        https://doc.qt.io/qt-6/qproximityreading.html#close-prop

        **[read-only] close : const bool**

        This property holds a value indicating if something is close.

        Set to true if something is close. Set to false is nothing is close.

        **Access functions:**

        bool **close** () const

        **See also** **QProximityReading_Units** .

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QDesignerFormEditorInterface(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdesignerformeditorinterface.html

    **Detailed Description**

    **Qt Designer** 's current QDesignerFormEditorInterface object holds
    information about all **Qt Designer** 's components: The action editor, the
    object inspector, the property editor, the widget box, and the extension and
    form window managers. QDesignerFormEditorInterface contains a collection of
    functions that provides interfaces to all these components. They are
    typically used to query (and manipulate) the respective component. For
    example:

    **QDesignerObjectInspectorInterface**  *objectInspector = 0;
    objectInspector = formEditor->objectInspector();
    **QDesignerFormWindowManagerInterface**  *manager = 0;
                manager =
    formEditor->formWindowManager();
    objectInspector->setFormWindow(manager->formWindow(0));

    QDesignerFormEditorInterface is not intended to be instantiated directly. A
    pointer to **Qt Designer** 's current QDesignerFormEditorInterface object
    (`formEditor` in the example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter. When
    implementing a custom widget plugin, you must subclass the
    **QDesignerCustomWidgetInterface**  to expose your plugin to **Qt
    Designer**.

    QDesignerFormEditorInterface also provides functions that can set the action
    editor, property editor, object inspector and widget box. These are only
    useful if you want to provide your own custom components.

    If designer is embedded in another program, one could to provide its own
    settings manager. The manager is used by the components of **Qt Designer**
    to store/retrieve persistent configuration settings. The default manager
    uses **QSettings**  as the backend.

    Finally, QDesignerFormEditorInterface provides the **topLevel** () function
    that returns **Qt Designer** 's top-level widget.

    **See also** **QDesignerCustomWidgetInterface** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#QDesignerFormEd
        itorInterface

        **QDesignerFormEditorInterface::QDesignerFormEditorInterface(QObject *
        parent = nullptr)**

        Constructs a QDesignerFormEditorInterface object with the given
        **parent**.
        """
        ...

    def setActionEditor(self, actionEditor: QDesignerActionEditorInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setActionEditor

        **void QDesignerFormEditorInterface::setActionEditor(QDesignerActionEdit
        orInterface * actionEditor )**

        Sets **Qt Designer** 's action editor to be the specified
        **actionEditor**.

        **See also** **actionEditor** ().
        """
        ...

    def setObjectInspector(
        self, objectInspector: "QDesignerObjectInspectorInterface"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setObjectInspec
        tor

        **void QDesignerFormEditorInterface::setObjectInspector(QDesignerObjectI
        nspectorInterface * objectInspector )**

        Sets **Qt Designer** 's object inspector to be the specified
        **objectInspector**.

        **See also** **objectInspector** ().
        """
        ...

    def setPropertyEditor(
        self, propertyEditor: "QDesignerPropertyEditorInterface"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setPropertyEdit
        or

        **void QDesignerFormEditorInterface::setPropertyEditor(QDesignerProperty
        EditorInterface * propertyEditor )**

        Sets **Qt Designer** 's property editor to be the specified
        **propertyEditor**.

        **See also** **propertyEditor** ().
        """
        ...

    def setWidgetBox(self, widgetBox: "QDesignerWidgetBoxInterface") -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setWidgetBox

        **void
        QDesignerFormEditorInterface::setWidgetBox(QDesignerWidgetBoxInterface *
        widgetBox )**

        Sets **Qt Designer** 's widget box to be the specified **widgetBox**.

        **See also** **widgetBox** ().
        """
        ...

    def actionEditor(self) -> QDesignerActionEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#actionEditor

        **QDesignerActionEditorInterface
        *QDesignerFormEditorInterface::actionEditor() const**

        Returns an interface to **Qt Designer** 's action editor.

        **See also** **setActionEditor** ().
        """
        ...

    def formWindowManager(self) -> "QDesignerFormWindowManagerInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#formWindowManag
        er

        **QDesignerFormWindowManagerInterface
        *QDesignerFormEditorInterface::formWindowManager() const**

        Returns an interface to **Qt Designer** 's form window manager.
        """
        ...

    def objectInspector(self) -> "QDesignerObjectInspectorInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#objectInspector

        **QDesignerObjectInspectorInterface
        *QDesignerFormEditorInterface::objectInspector() const**

        Returns an interface to **Qt Designer** 's object inspector.

        **See also** **setObjectInspector** ().
        """
        ...

    def propertyEditor(self) -> "QDesignerPropertyEditorInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#propertyEditor

        **QDesignerPropertyEditorInterface
        *QDesignerFormEditorInterface::propertyEditor() const**

        Returns an interface to **Qt Designer** 's property editor.

        **See also** **setPropertyEditor** ().
        """
        ...

    def widgetBox(self) -> "QDesignerWidgetBoxInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#widgetBox

        **QDesignerWidgetBoxInterface *QDesignerFormEditorInterface::widgetBox()
        const**

        Returns an interface to **Qt Designer** 's widget box.

        **See also** **setWidgetBox** ().
        """
        ...

    def topLevel(self) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#topLevel

        **QWidget *QDesignerFormEditorInterface::topLevel() const**

        Returns **Qt Designer** 's top-level widget.
        """
        ...

    def extensionManager(self) -> "QExtensionManager":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#extensionManage
        r

        **QExtensionManager *QDesignerFormEditorInterface::extensionManager()
        const**

        Returns an interface to **Qt Designer** 's extension manager.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtRemoteObjects import *


class QRemoteObjectRegistryHost(QRemoteObjectHostBase):
    """
    https://doc.qt.io/qt-6/qremoteobjectregistryhost.html

    **Detailed Description**

    The QRemoteObjectRegistryHost class provides an entry point to a
    **QtRemoteObjects**  network. A network can be as simple as two Nodes, or an
    arbitrarily complex set of processes and devices.

    A QRemoteObjectRegistryHost has the same capability that a
    **QRemoteObjectHost**  has (which includes everything a
    **QRemoteObjectNode**  supports), and in addition is the owner of the
    Registry. Any **QRemoteObjectHost**  node that connects to this Node will
    have all of their Source objects made available by the Registry.

    Nodes only support connection to one **registry** , calling
    **QRemoteObjectNode::setRegistryUrl**  when a Registry is already set is
    considered an error. For something like a secure and insecure network (where
    different Registries would be applicable), the recommendation is to create
    separate Nodes to connect to each, in effect creating two independent Qt
    Remote Objects networks.

    Nodes may connect to each other directly using **connectToNode** , or they
    can use the **QRemoteObjectRegistry**  to simplify connections.

    The **QRemoteObjectRegistry**  is a special Replica available to every Node
    that connects to the Registry Url. It knows how to connect to every
    QRemoteObjectSource object on the network.

    **See also** **QRemoteObjectNode**  and **QRemoteObjectHost** .
    """

    def __init__(
        self,
        registryAddress: QtCore.QUrl = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectregistryhost.html#QRemoteObjectRegis
        tryHost

        **QRemoteObjectRegistryHost::QRemoteObjectRegistryHost(const QUrl &
        registryAddress = QUrl(), QObject * parent = nullptr)**

        Constructs a new QRemoteObjectRegistryHost Node with the given
        **parent**. RegistryHost Nodes have the same functionality as
        **QRemoteObjectHost**  Nodes, except rather than being able to connect
        to a **QRemoteObjectRegistry** , the provided Host **QUrl**  (
        **registryAddress** ) becomes the address of the registry for other
        Nodes to connect to.
        """
        ...

    def setRegistryUrl(self, registryUrl: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectregistryhost.html#setRegistryUrl

        **[override virtual] bool
        QRemoteObjectRegistryHost::setRegistryUrl(const QUrl & registryUrl )**

        Reimplements an access function for property:
        **QRemoteObjectNode::registryUrl** .

        This method can be used to set the address of this Node to
        **registryUrl** (used for other Nodes to connect to this one), if the
        **QUrl**  isn't set in the constructor. Since this Node becomes the
        Registry, calling this setter method causes this Node to use the url as
        the host address. All other Node's use the
        **QRemoteObjectNode::setRegistryUrl**  method initiate a connection to
        the Registry.

        Returns `true` if the registry address is set, otherwise `false`.

        **See also** **QRemoteObjectRegistryHost** () and
        **QRemoteObjectNode::setRegistryUrl** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlFileSelector(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlfileselector.html

    **Detailed Description**

    QQmlFileSelector will automatically apply a **QFileSelector**  to qml file
    and asset paths.

    It is used as follows:

    **QQmlEngine**  engine;
        **QQmlFileSelector** * selector = new
    **QQmlFileSelector** (&engine);

    Then you can swap out files like so:

    main.qml
        Component.qml
        asset.png
        +unix/Component.qml
    +mac/asset.png

    In this example, main.qml will normally use Component.qml for the Component
    type. However on a unix platform, the unix selector will be present and the
    +unix/Component.qml version will be used instead. Note that this acts like
    swapping out Component.qml with +unix/Component.qml, so when using
    Component.qml you should not need to alter any paths based on which version
    was selected.

    For example, to pass the "asset.png" file path around you would refer to it
    just as "asset.png" in all of main.qml, Component.qml, and
    +linux/Component.qml. It will be replaced with +mac/asset.png on Mac
    platforms in all cases.

    For a list of available selectors, see `QFileSelector`.

    Your platform may also provide additional selectors for you to use. As
    specified by **QFileSelector** , directories used for selection must start
    with a '+' character, so you will not accidentally trigger this feature
    unless you have directories with such names inside your project.

    If a new QQmlFileSelector is set on the engine, the old one will be
    replaced.
    """

    def __init__(
        self, engine: QQmlEngine, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlfileselector.html#QQmlFileSelector

        **QQmlFileSelector::QQmlFileSelector(QQmlEngine * engine , QObject *
        parent = nullptr)**

        Creates a new QQmlFileSelector with parent object **parent** , which
        includes its own **QFileSelector** . **engine** is the **QQmlEngine**
        you wish to apply file selectors to. It will also take ownership of the
        QQmlFileSelector.
        """
        ...

    def selector(self) -> QtCore.QFileSelector:
        """
        https://doc.qt.io/qt-6/qqmlfileselector.html#selector

        **[since 5.7] QFileSelector *QQmlFileSelector::selector() const**

        Returns the **QFileSelector**  instance used by the **QQmlFileSelector**
        .

        This function was introduced in Qt 5.7.

        **See also** **setSelector** ().
        """
        ...

    def setExtraSelectors(self, strings: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qqmlfileselector.html#setExtraSelectors

        **void QQmlFileSelector::setExtraSelectors(const QStringList & strings
        )**

        Adds extra selectors contained in **strings** to the current
        **QFileSelector**  being used. Use this when extra selectors are all you
        need to avoid having to create your own **QFileSelector**  instance.
        """
        ...

    def setSelector(self, selector: QtCore.QFileSelector) -> None:
        """
        https://doc.qt.io/qt-6/qqmlfileselector.html#setSelector

        **void QQmlFileSelector::setSelector(QFileSelector * selector )**

        Sets the **QFileSelector**  instance for use by the **QQmlFileSelector**
        to **selector**. **QQmlFileSelector**  does not take ownership of the
        new **QFileSelector** . To reset **QQmlFileSelector**  to use its
        internal **QFileSelector**  instance, call setSelector(`nullptr`).

        **See also** **selector** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class pyqtBoundSignal:
    signal: str = ...

    def __getitem__(self, key: object) -> "pyqtBoundSignal":
        ...

    def connect(self, slot: "PYQT_SLOT") -> "QMetaObject.Connection":
        ...

    @typing.overload
    def disconnect(self) -> None:
        ...

    @typing.overload
    def disconnect(
        self, slot: typing.Union["PYQT_SLOT", "QMetaObject.Connection"]
    ) -> None:
        ...

    def emit(self, *args: typing.Any) -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtGui import *
import enum


class QTextListFormat(QTextFormat):
    """
    https://doc.qt.io/qt-6/qtextlistformat.html

    **Detailed Description**

    A list is composed of one or more items, represented as text blocks. The
    list's format specifies the appearance of items in the list. In particular,
    it determines the indentation and the style of each item.

    The indentation of the items is an integer value that causes each item to be
    offset from the left margin by a certain amount. This value is read with
    **indent** () and set with **setIndent** ().

    The style used to decorate each item is set with **setStyle** () and can be
    read with the **style** () function. The style controls the type of bullet
    points and numbering scheme used for items in the list. Note that lists that
    use the decimal numbering scheme begin counting at 1 rather than 0.

    Style properties can be set to further configure the appearance of list
    items; for example, the ListNumberPrefix and ListNumberSuffix properties can
    be used to customize the numbers used in an ordered list so that they appear
    as (1), (2), (3), etc.:

    **QTextListFormat**  listFormat;
    listFormat.setStyle(**QTextListFormat** ::ListDecimal);
    listFormat.setNumberPrefix("(");
        listFormat.setNumberSuffix(")");
    cursor.insertList(listFormat);

    **See also** **QTextList** .
    """

    class Style(enum.Enum):
        ListDisc: QTextListFormat = ...
        ListCircle: QTextListFormat = ...
        ListSquare: QTextListFormat = ...
        ListDecimal: QTextListFormat = ...
        ListLowerAlpha: QTextListFormat = ...
        ListUpperAlpha: QTextListFormat = ...
        ListLowerRoman: QTextListFormat = ...
        ListUpperRoman: QTextListFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#QTextListFormat

        **QTextListFormat::QTextListFormat()**

        Constructs a new list format object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextListFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#QTextListFormat

        **QTextListFormat::QTextListFormat()**

        Constructs a new list format object.
        """
        ...

    def setNumberSuffix(self, ns: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#setNumberSuffix

        **void QTextListFormat::setNumberSuffix(const QString & numberSuffix )**

        Sets the list format's number suffix to the string specified by
        **numberSuffix**. This can be used with all sorted list types. It does
        not have any effect on unsorted list types.

        The default suffix is ".".

        **See also** **numberSuffix** ().
        """
        ...

    def setNumberPrefix(self, np: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#setNumberPrefix

        **void QTextListFormat::setNumberPrefix(const QString & numberPrefix )**

        Sets the list format's number prefix to the string specified by
        **numberPrefix**. This can be used with all sorted list types. It does
        not have any effect on unsorted list types.

        The default prefix is an empty string.

        **See also** **numberPrefix** ().
        """
        ...

    def numberSuffix(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#numberSuffix

        **QString QTextListFormat::numberSuffix() const**

        Returns the list format's number suffix.

        **See also** **setNumberSuffix** ().
        """
        ...

    def numberPrefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#numberPrefix

        **QString QTextListFormat::numberPrefix() const**

        Returns the list format's number prefix.

        **See also** **setNumberPrefix** ().
        """
        ...

    def setIndent(self, aindent: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#setIndent

        **void QTextListFormat::setIndent(int indentation )**

        Sets the list format's **indentation**. The indentation is multiplied by
        the **QTextDocument::indentWidth**  property to get the effective indent
        in pixels.

        **See also** **indent** ().
        """
        ...

    def setStyle(self, astyle: "QTextListFormat.Style") -> None:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#setStyle

        **void QTextListFormat::setStyle(QTextListFormat::Style style )**

        Sets the list format's **style**.

        **See also** **style** () and **Style** .
        """
        ...

    def indent(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#indent

        **int QTextListFormat::indent() const**

        Returns the list format's indentation. The indentation is multiplied by
        the **QTextDocument::indentWidth**  property to get the effective indent
        in pixels.

        **See also** **setIndent** ().
        """
        ...

    def style(self) -> "QTextListFormat.Style":
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#style

        **QTextListFormat::Style QTextListFormat::style() const**

        Returns the list format's style.

        **See also** **setStyle** () and **Style** .
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextlistformat.html#isValid

        **bool QTextListFormat::isValid() const**

        Returns `true` if this list format is valid; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtDBus import *


class QDBusInterface(QDBusAbstractInterface):
    """
    https://doc.qt.io/qt-6/qdbusinterface.html

    **Detailed Description**

    QDBusInterface is a generic accessor class that is used to place calls to
    remote objects, connect to signals exported by remote objects and get/set
    the value of remote properties. This class is useful for dynamic access to
    remote objects: that is, when you do not have a generated code that
    represents the remote interface.

    Calls are usually placed by using the **call** () function, which constructs
    the message, sends it over the bus, waits for the reply and decodes the
    reply. Signals are connected to by using the normal **QObject::connect** ()
    function. Finally, properties are accessed using the **QObject::property**
    () and **QObject::setProperty** () functions.

    The following code snippet demonstrates how to perform a mathematical
    operation of `"2 + 2"` in a remote application called
    `com.example.Calculator`, accessed via the session bus.

    QDBusInterface remoteApp( "com.example.Calculator",
    "/Calculator/Operations",
    "org.mathematics.RPNCalculator" );
        remoteApp.call( "PushOperand", 2 );
    remoteApp.call( "PushOperand", 2 );
        remoteApp.call( "ExecuteOperation",
    "+" );
        **QDBusReply** <int> reply = remoteApp.call( "PopOperand" );
    if ( reply.isValid() )
            printf( "%d", reply.value() );          //
    prints 4

    **See also** **Qt D-Bus XML compiler (qdbusxml2cpp)** .
    """

    def __init__(
        self,
        service: str,
        path: str,
        interface: str = ...,
        connection: QDBusConnection = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdbusinterface.html#QDBusInterface-1

        **QDBusInterface::QDBusInterface(const QString & service , const QString
        & path , const QString & interface = QString(), const QDBusConnection &
        connection = QDBusConnection::sessionBus(), QObject * parent =
        nullptr)**

        Creates a dynamic QDBusInterface object associated with the interface
        **interface** on object at path **path** on service **service** , using
        the given **connection**. If **interface** is an empty string, the
        object created will refer to the merging of all interfaces found by
        introspecting that object. Otherwise if **interface** is not empty, the
        QDBusInterface object will be cached to speedup further creations of the
        same interface.

        **parent** is passed to the base class constructor.

        If the remote service **service** is not present or if an error occurs
        trying to obtain the description of the remote interface **interface** ,
        the object created will not be valid (see **isValid** ()).
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QUndoCommand(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qundocommand.html

    **Detailed Description**

    For an overview of Qt's Undo Framework, see the **overview document** .

    A QUndoCommand represents a single editing action on a document; for
    example, inserting or deleting a block of text in a text editor.
    QUndoCommand can apply a change to the document with **redo** () and undo
    the change with **undo** (). The implementations for these functions must be
    provided in a derived class.

    class AppendText : public **QUndoCommand**
        {
        public:
    AppendText(**QString**  *doc, const **QString**  &text)
                :
    m_document(doc), m_text(text) { setText("append text"); }
            void
    undo() override
                { m_document->chop(m_text.length()); }
    void redo() override
                { m_document->append(m_text); }
    private:
            **QString**  *m_document;
            **QString**  m_text;
    };

    A QUndoCommand has an associated **text** (). This is a short string
    describing what the command does. It is used to update the text properties
    of the stack's undo and redo actions; see **QUndoStack::createUndoAction**
    () and **QUndoStack::createRedoAction** ().

    QUndoCommand objects are owned by the stack they were pushed on.
    **QUndoStack**  deletes a command if it has been undone and a new command is
    pushed. For example:

    MyCommand *command1 = new MyCommand();
        stack->push(command1);
    MyCommand *command2 = new MyCommand();
        stack->push(command2);
    stack->undo();

        MyCommand *command3 = new MyCommand();
    stack->push(command3); // command2 gets deleted

    In effect, when a command is pushed, it becomes the top-most command on the
    stack.

    To support command compression, QUndoCommand has an **id** () and the
    virtual function **mergeWith** (). These functions are used by
    **QUndoStack::push** ().

    To support command macros, a QUndoCommand object can have any number of
    child commands. Undoing or redoing the parent command will cause the child
    commands to be undone or redone. A command can be assigned to a parent
    explicitly in the constructor. In this case, the command will be owned by
    the parent.

    The parent in this case is usually an empty command, in that it doesn't
    provide its own implementation of **undo** () and **redo** (). Instead, it
    uses the base implementations of these functions, which simply call **undo**
    () or **redo** () on all its children. The parent should, however, have a
    meaningful **text** ().

    **QUndoCommand**  *insertRed = new **QUndoCommand** (); // an empty command
    insertRed->setText("insert red text");

        new InsertText(document,
    idx, text, insertRed); // becomes child of insertRed
        new
    SetColor(document, idx, text.length(), Qt::red, insertRed);
    stack.push(insertRed);

    Another way to create macros is to use the convenience functions
    **QUndoStack::beginMacro** () and **QUndoStack::endMacro** ().

    **See also** **QUndoStack** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional["QUndoCommand"] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qundocommand.html#QUndoCommand

        **QUndoCommand::QUndoCommand(QUndoCommand * parent = nullptr)**

        Constructs a QUndoCommand object with parent **parent**.

        If **parent** is not `nullptr`, this command is appended to parent's
        child list. The parent command then owns this command and will delete it
        in its destructor.

        **See also** **~QUndoCommand** ().
        """
        ...

    @typing.overload
    def __init__(
        self, text: str, parent: typing.Optional["QUndoCommand"] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qundocommand.html#QUndoCommand-1

        **QUndoCommand::QUndoCommand(const QString & text , QUndoCommand *
        parent = nullptr)**

        Constructs a QUndoCommand object with the given **parent** and **text**.

        If **parent** is not `nullptr`, this command is appended to parent's
        child list. The parent command then owns this command and will delete it
        in its destructor.

        **See also** **~QUndoCommand** ().
        """
        ...

    def setObsolete(self, obsolete: bool) -> None:
        """
        https://doc.qt.io/qt-6/qundocommand.html#setObsolete

        **[since 5.9] void QUndoCommand::setObsolete(bool obsolete )**

        Sets whether the command is obsolete to **obsolete**.

        This function was introduced in Qt 5.9.

        **See also** **isObsolete** (), **mergeWith** (), **QUndoStack::push**
        (), **QUndoStack::undo** (), and **QUndoStack::redo** ().
        """
        ...

    def isObsolete(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundocommand.html#isObsolete

        **[since 5.9] bool QUndoCommand::isObsolete() const**

        Returns whether the command is obsolete.

        The boolean is used for the automatic removal of commands that are not
        necessary in the stack anymore. The isObsolete function is checked in
        the functions **QUndoStack::push** (), **QUndoStack::undo** (),
        **QUndoStack::redo** (), and **QUndoStack::setIndex** ().

        This function was introduced in Qt 5.9.

        **See also** **setObsolete** (), **mergeWith** (), **QUndoStack::push**
        (), **QUndoStack::undo** (), and **QUndoStack::redo** ().
        """
        ...

    def actionText(self) -> str:
        """
        https://doc.qt.io/qt-6/qundocommand.html#actionText

        **QString QUndoCommand::actionText() const**

        Returns a short text string describing what this command does; for
        example, "insert text".

        The text is used when the text properties of the stack's undo and redo
        actions are updated.

        **See also** **text** (), **setText** (),
        **QUndoStack::createUndoAction** (), and
        **QUndoStack::createRedoAction** ().
        """
        ...

    def child(self, index: int) -> "QUndoCommand":
        """
        https://doc.qt.io/qt-6/qundocommand.html#child

        **const QUndoCommand *QUndoCommand::child(int index ) const**

        Returns the child command at **index**.

        **See also** **childCount** () and **QUndoStack::command** ().
        """
        ...

    def childCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qundocommand.html#childCount

        **int QUndoCommand::childCount() const**

        Returns the number of child commands in this command.

        **See also** **child** ().
        """
        ...

    def undo(self) -> None:
        """
        https://doc.qt.io/qt-6/qundocommand.html#undo

        **[virtual] void QUndoCommand::undo()**

        Reverts a change to the document. After undo() is called, the state of
        the document should be the same as before **redo** () was called. This
        function must be implemented in the derived class. Calling
        **QUndoStack::push** (), **QUndoStack::undo** () or **QUndoStack::redo**
        () from this function leads to undefined beahavior.

        The default implementation calls undo() on all child commands in reverse
        order.

        **See also** **redo** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qundocommand.html#text

        **QString QUndoCommand::text() const**

        Returns a short text string describing what this command does; for
        example, "insert text".

        The text is used for names of items in **QUndoView** .

        **See also** **actionText** (), **setText** (),
        **QUndoStack::createUndoAction** (), and
        **QUndoStack::createRedoAction** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qundocommand.html#setText

        **void QUndoCommand::setText(const QString & text )**

        Sets the command's text to be the **text** specified.

        The specified text should be a short user-readable string describing
        what this command does.

        If you need to have two different strings for **text** () and
        **actionText** (), separate them with "\\n" and pass into this function.
        Even if you do not use this feature for English strings during
        development, you can still let translators use two different strings in
        order to match specific languages' needs. The described feature and the
        function **actionText** () are available since Qt 4.8.

        **See also** **text** (), **actionText** (),
        **QUndoStack::createUndoAction** (), and
        **QUndoStack::createRedoAction** ().
        """
        ...

    def redo(self) -> None:
        """
        https://doc.qt.io/qt-6/qundocommand.html#redo

        **[virtual] void QUndoCommand::redo()**

        Applies a change to the document. This function must be implemented in
        the derived class. Calling **QUndoStack::push** (), **QUndoStack::undo**
        () or **QUndoStack::redo** () from this function leads to undefined
        beahavior.

        The default implementation calls redo() on all child commands.

        **See also** **undo** ().
        """
        ...

    def mergeWith(self, other: "QUndoCommand") -> bool:
        """
        https://doc.qt.io/qt-6/qundocommand.html#mergeWith

        **[virtual] bool QUndoCommand::mergeWith(const QUndoCommand * command
        )**

        Attempts to merge this command with **command**. Returns `true` on
        success; otherwise returns `false`.

        If this function returns `true`, calling this command's **redo** () must
        have the same effect as redoing both this command and **command**.
        Similarly, calling this command's **undo** () must have the same effect
        as undoing **command** and this command.

        **QUndoStack**  will only try to merge two commands if they have the
        same id, and the id is not -1.

        The default implementation returns `false`.

        bool AppendText::mergeWith(const **QUndoCommand**  *other)
            {
        if (other->id() != id()) // make sure other is also an AppendText
        command
                    return false;
                m_text += static_cast<const
        AppendText\\*>(other)->m_text;
                return true;
            }

        **See also** **id** () and **QUndoStack::push** ().
        """
        ...

    def id(self) -> int:
        """
        https://doc.qt.io/qt-6/qundocommand.html#id

        **[virtual] int QUndoCommand::id() const**

        Returns the ID of this command.

        A command ID is used in command compression. It must be an integer
        unique to this command's class, or -1 if the command doesn't support
        compression.

        If the command supports compression this function must be overridden in
        the derived class to return the correct ID. The base implementation
        returns -1.

        **QUndoStack::push** () will only try to merge two commands if they have
        the same ID, and the ID is not -1.

        **See also** **mergeWith** () and **QUndoStack::push** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QAudio import QAudio as QAudio
from ._QAudioBuffer import QAudioBuffer as QAudioBuffer
from ._QAudioDecoder import QAudioDecoder as QAudioDecoder
from ._QAudioDevice import QAudioDevice as QAudioDevice
from ._QAudioFormat import QAudioFormat as QAudioFormat
from ._QAudioInput import QAudioInput as QAudioInput
from ._QAudioOutput import QAudioOutput as QAudioOutput
from ._QAudioSink import QAudioSink as QAudioSink
from ._QAudioSource import QAudioSource as QAudioSource
from ._QCamera import QCamera as QCamera
from ._QCameraFormat import QCameraFormat as QCameraFormat
from ._QCameraDevice import QCameraDevice as QCameraDevice
from ._QImageCapture import QImageCapture as QImageCapture
from ._QMediaCaptureSession import QMediaCaptureSession as QMediaCaptureSession
from ._QMediaDevices import QMediaDevices as QMediaDevices
from ._QMediaFormat import QMediaFormat as QMediaFormat
from ._QMediaMetaData import QMediaMetaData as QMediaMetaData
from ._QMediaPlayer import QMediaPlayer as QMediaPlayer
from ._QMediaRecorder import QMediaRecorder as QMediaRecorder
from ._QMediaTimeRange import QMediaTimeRange as QMediaTimeRange
from ._QSoundEffect import QSoundEffect as QSoundEffect
from ._QVideoFrame import QVideoFrame as QVideoFrame
from ._QVideoFrameFormat import QVideoFrameFormat as QVideoFrameFormat
from ._QVideoSink import QVideoSink as QVideoSink



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsProxyWidget(QGraphicsWidget):
    """
    https://doc.qt.io/qt-6/qgraphicsproxywidget.html

    **Detailed Description**

    QGraphicsProxyWidget embeds **QWidget** -based widgets, for example, a
    **QPushButton** , **QFontComboBox** , or even **QFileDialog** , into
    **QGraphicsScene** . It forwards events between the two objects and
    translates between **QWidget** 's integer-based geometry and
    **QGraphicsWidget** 's qreal-based geometry. QGraphicsProxyWidget supports
    all core features of **QWidget** , including tab focus, keyboard input, Drag
    & Drop, and popups. You can also embed complex widgets, e.g., widgets with
    subwidgets.

    Example:

    int main(int argc, char **argv)
        {
            **QApplication**  app(argc,
    argv);

            **QTabWidget**  *tabWidget = new **QTabWidget** ;
    **QGraphicsScene**  scene;
            **QGraphicsProxyWidget**  *proxy =
    scene.addWidget(tabWidget);

            **QGraphicsView**  view(&scene);
    view.show();

            return app.exec();
        }

    QGraphicsProxyWidget takes care of automatically embedding popup children of
    embedded widgets through creating a child proxy for each popup. This means
    that when an embedded **QComboBox**  shows its popup list, a new
    QGraphicsProxyWidget is created automatically, embedding the popup, and
    positioning it correctly. This only works if the popup is child of the
    embedded widget (for example **QToolButton::setMenu** () requires the
    **QMenu**  instance to be child of the **QToolButton** ).

    **Embedding a Widget with QGraphicsProxyWidget**

    There are two ways to embed a widget using QGraphicsProxyWidget. The most
    common way is to pass a widget pointer to **QGraphicsScene::addWidget** ()
    together with any relevant **Qt::WindowFlags** . This function returns a
    pointer to a QGraphicsProxyWidget. You can then choose to reparent or
    position either the proxy, or the embedded widget itself.

    For example, in the code snippet below, we embed a group box into the proxy:

    **QGroupBox**  *groupBox = new **QGroupBox** ("Contact Details");
    **QLabel**  *numberLabel = new **QLabel** ("Telephone number");
    **QLineEdit**  *numberEdit = new **QLineEdit** ;

        **QFormLayout**
    *layout = new **QFormLayout** ;
        layout->addRow(numberLabel, numberEdit);
    groupBox->setLayout(layout);

        **QGraphicsScene**  scene;
    **QGraphicsProxyWidget**  *proxy = scene.addWidget(groupBox);
    **QGraphicsView**  view(&scene);
        view.show();

    The image below is the output obtained with its contents margin and contents
    rect labeled.

    ![](images/qgraphicsproxywidget-embed.png)

    Alternatively, you can start by creating a new QGraphicsProxyWidget item,
    and then call **setWidget** () to embed a **QWidget**  later. The **widget**
    () function returns a pointer to the embedded widget. QGraphicsProxyWidget
    shares ownership with **QWidget** , so if either of the two widgets are
    destroyed, the other widget will be automatically destroyed as well.

    **Synchronizing Widget States**

    QGraphicsProxyWidget keeps its state in sync with the embedded widget. For
    example, if the proxy is hidden or disabled, the embedded widget will be
    hidden or disabled as well, and vice versa. When the widget is embedded by
    calling addWidget(), QGraphicsProxyWidget copies the state from the widget
    into the proxy, and after that, the two will stay synchronized where
    possible. By default, when you embed a widget into a proxy, both the widget
    and the proxy will be visible because a **QGraphicsWidget**  is visible when
    created (you do not have to call **show** ()). If you explicitly hide the
    embedded widget, the proxy will also become invisible.

    Example:

    **QGraphicsScene**  scene;

        **QLineEdit**  *edit = new **QLineEdit**
    ;
        **QGraphicsProxyWidget**  *proxy = scene.addWidget(edit);
    edit->isVisible();  // returns true
        proxy->isVisible(); // also returns
    true

        edit->hide();

        edit->isVisible();  // returns false
    proxy->isVisible(); // also returns false

    QGraphicsProxyWidget maintains symmetry for the following states:

    **QWidget**  stateQGraphicsProxyWidget stateNotes
    **QWidget::enabled**
    QGraphicsProxyWidget::enabled
    **QWidget::visible**
    QGraphicsProxyWidget::visibleThe explicit state is also symmetric.
    **QWidget::geometry** QGraphicsProxyWidget::geometryGeometry is only
    guaranteed to be symmetric while the embedded widget is visible.
    **QWidget::layoutDirection** QGraphicsProxyWidget::layoutDirection
    **QWidget::style** QGraphicsProxyWidget::style
    **QWidget::palette**
    QGraphicsProxyWidget::palette
    **QWidget::font** QGraphicsProxyWidget::font
    **QWidget::cursor** QGraphicsProxyWidget::cursorThe embedded widget
    overrides the proxy widget cursor. The proxy cursor changes depending on
    which embedded subwidget is currently under the mouse.
    **QWidget::sizeHint** ()**QGraphicsProxyWidget::sizeHint** ()All size hint
    functionality from the embedded widget is forwarded by the proxy.
    QWidget::getContentsMargins()**QGraphicsProxyWidget::getContentsMargins**
    ()Updated once by **setWidget** ().
    **QWidget::windowTitle**
    QGraphicsProxyWidget::windowTitleUpdated once by **setWidget** ().

    **Note:****QGraphicsScene**  keeps the embedded widget in a special state
    that prevents it from disturbing other widgets (both embedded and not
    embedded) while the widget is embedded. In this state, the widget may differ
    slightly in behavior from when it is not embedded.

    **Warning:** This class is provided for convenience when bridging QWidgets
    and QGraphicsItems, it should not be used for high-performance scenarios. In
    particular, embedding widgets into a scene that is then displayed through a
    **QGraphicsView**  that uses an OpenGL viewport will not work for all
    combinations.

    **See also** **QGraphicsScene::addWidget** () and **QGraphicsWidget** .
    """

    def __init__(
        self,
        parent: typing.Optional[QGraphicsItem] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#QGraphicsProxyWidget

        **QGraphicsProxyWidget::QGraphicsProxyWidget(QGraphicsItem * parent =
        nullptr, Qt::WindowFlags wFlags = Qt::WindowFlags())**

        Constructs a new QGraphicsProxy widget. **parent** and **wFlags** are
        passed to **QGraphicsItem** 's constructor.
        """
        ...

    def inputMethodEvent(self, event: QtGui.QInputMethodEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#inputMethodEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::inputMethodEvent(QInputMethodEvent * event )**

        Reimplements: **QGraphicsItem::inputMethodEvent** (QInputMethodEvent
        *event).
        """
        ...

    def inputMethodQuery(self, query: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#inputMethodQuery

        **[override virtual protected] QVariant
        QGraphicsProxyWidget::inputMethodQuery(Qt::InputMethodQuery query )
        const**

        Reimplements: **QGraphicsItem::inputMethodQuery(Qt::InputMethodQuery
        query) const** .
        """
        ...

    def newProxyWidget(self, a0: QWidget) -> "QGraphicsProxyWidget":
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#newProxyWidget

        **[protected slot] QGraphicsProxyWidget
        *QGraphicsProxyWidget::newProxyWidget(const QWidget * child )**

        Creates a proxy widget for the given **child** of the widget contained
        in this proxy.

        You should not call this function directly; use
        **QGraphicsProxyWidget::createProxyForChildWidget** () instead.

        This function is a fake virtual slot that you can reimplement in your
        subclass in order to control how new proxy widgets are created. The
        default implementation returns a proxy created with the
        **QGraphicsProxyWidget** () constructor with this proxy widget as the
        parent.

        **See also** **createProxyForChildWidget** ().
        """
        ...

    def dropEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#dropEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::dropEvent(QGraphicsSceneDragDropEvent * event )**

        Reimplements: **QGraphicsItem::dropEvent** (QGraphicsSceneDragDropEvent
        *event).
        """
        ...

    def dragMoveEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#dragMoveEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::dragMoveEvent(QGraphicsSceneDragDropEvent * event
        )**

        Reimplements: **QGraphicsItem::dragMoveEvent**
        (QGraphicsSceneDragDropEvent *event).
        """
        ...

    def dragLeaveEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#dragLeaveEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::dragLeaveEvent(QGraphicsSceneDragDropEvent * event
        )**

        Reimplements: **QGraphicsItem::dragLeaveEvent**
        (QGraphicsSceneDragDropEvent *event).
        """
        ...

    def dragEnterEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#dragEnterEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::dragEnterEvent(QGraphicsSceneDragDropEvent * event
        )**

        Reimplements: **QGraphicsItem::dragEnterEvent**
        (QGraphicsSceneDragDropEvent *event).
        """
        ...

    def resizeEvent(self, event: "QGraphicsSceneResizeEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#resizeEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::resizeEvent(QGraphicsSceneResizeEvent * event )**

        Reimplements: **QGraphicsWidget::resizeEvent**
        (QGraphicsSceneResizeEvent *event).
        """
        ...

    def sizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#sizeHint

        **[override virtual protected] QSizeF
        QGraphicsProxyWidget::sizeHint(Qt::SizeHint which , const QSizeF &
        constraint = QSizeF()) const**

        Reimplements: **QGraphicsWidget::sizeHint(Qt::SizeHint which, const
        QSizeF &constraint) const** .
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#focusNextPrevChild

        **[override virtual protected] bool
        QGraphicsProxyWidget::focusNextPrevChild(bool next )**

        Reimplements: **QGraphicsWidget::focusNextPrevChild** (bool next).
        """
        ...

    def focusOutEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#focusOutEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::focusOutEvent(QFocusEvent * event )**

        Reimplements: **QGraphicsWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#focusInEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::focusInEvent(QFocusEvent * event )**

        Reimplements: **QGraphicsWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def keyReleaseEvent(self, event: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#keyReleaseEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::keyReleaseEvent(QKeyEvent * event )**

        Reimplements: **QGraphicsItem::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, event: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#keyPressEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::keyPressEvent(QKeyEvent * event )**

        Reimplements: **QGraphicsItem::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def wheelEvent(self, event: "QGraphicsSceneWheelEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#wheelEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::wheelEvent(QGraphicsSceneWheelEvent * event )**

        Reimplements: **QGraphicsItem::wheelEvent** (QGraphicsSceneWheelEvent
        *event).
        """
        ...

    def mouseDoubleClickEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *
        event )**

        Reimplements: **QGraphicsItem::mouseDoubleClickEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#mouseReleaseEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent * event
        )**

        Reimplements: **QGraphicsItem::mouseReleaseEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def mousePressEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#mousePressEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::mousePressEvent(QGraphicsSceneMouseEvent * event
        )**

        Reimplements: **QGraphicsItem::mousePressEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#mouseMoveEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::mouseMoveEvent(QGraphicsSceneMouseEvent * event
        )**

        Reimplements: **QGraphicsItem::mouseMoveEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def ungrabMouseEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#ungrabMouseEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::ungrabMouseEvent(QEvent * event )**

        Reimplements: **QGraphicsWidget::ungrabMouseEvent** (QEvent *event).
        """
        ...

    def grabMouseEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#grabMouseEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::grabMouseEvent(QEvent * event )**

        Reimplements: **QGraphicsWidget::grabMouseEvent** (QEvent *event).
        """
        ...

    def hoverMoveEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#hoverMoveEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::hoverMoveEvent(QGraphicsSceneHoverEvent * event
        )**

        Reimplements: **QGraphicsWidget::hoverMoveEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def hoverLeaveEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#hoverLeaveEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::hoverLeaveEvent(QGraphicsSceneHoverEvent * event
        )**

        Reimplements: **QGraphicsWidget::hoverLeaveEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def hoverEnterEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#hoverEnterEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::hoverEnterEvent(QGraphicsSceneHoverEvent * event
        )**

        Reimplements: **QGraphicsItem::hoverEnterEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def contextMenuEvent(self, event: "QGraphicsSceneContextMenuEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#contextMenuEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::contextMenuEvent(QGraphicsSceneContextMenuEvent *
        event )**

        Reimplements: **QGraphicsItem::contextMenuEvent**
        (QGraphicsSceneContextMenuEvent *event).
        """
        ...

    def hideEvent(self, event: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#hideEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::hideEvent(QHideEvent * event )**

        Reimplements: **QGraphicsWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def showEvent(self, event: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#showEvent

        **[override virtual protected] void
        QGraphicsProxyWidget::showEvent(QShowEvent * event )**

        Reimplements: **QGraphicsWidget::showEvent** (QShowEvent *event).
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#eventFilter

        **[override virtual protected] bool
        QGraphicsProxyWidget::eventFilter(QObject * object , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#event

        **[override virtual protected] bool QGraphicsProxyWidget::event(QEvent *
        event )**

        Reimplements: **QGraphicsWidget::event** (QEvent *event).
        """
        ...

    def itemChange(
        self, change: QGraphicsItem.GraphicsItemChange, value: typing.Any
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#itemChange

        **[override virtual protected] QVariant
        QGraphicsProxyWidget::itemChange(QGraphicsItem::GraphicsItemChange
        change , const QVariant & value )**

        Reimplements: **QGraphicsWidget::itemChange**
        (QGraphicsItem::GraphicsItemChange change, const QVariant &value).
        """
        ...

    def createProxyForChildWidget(self, child: QWidget) -> "QGraphicsProxyWidget":
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#createProxyForChildWidg
        et

        **QGraphicsProxyWidget
        *QGraphicsProxyWidget::createProxyForChildWidget(QWidget * child )**

        Creates a proxy widget for the given **child** of the widget contained
        in this proxy.

        This function makes it possible to acquire proxies for non top-level
        widgets. For instance, you can embed a dialog, and then transform only
        one of its widgets.

        If the widget is already embedded, return the existing proxy widget.

        **See also** **newProxyWidget** () and **QGraphicsScene::addWidget** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#type

        **[override virtual] int QGraphicsProxyWidget::type() const**

        Reimplements: **QGraphicsWidget::type() const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: QWidget,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#paint

        **[override virtual] void QGraphicsProxyWidget::paint(QPainter * painter
        , const QStyleOptionGraphicsItem * option , QWidget * widget )**

        Reimplements: **QGraphicsWidget::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def setGeometry(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#setGeometry

        **[override virtual] void QGraphicsProxyWidget::setGeometry(const QRectF
        & rect )**

        Reimplements: **QGraphicsLayoutItem::setGeometry** (const QRectF &rect).
        """
        ...

    def subWidgetRect(self, widget: QWidget) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#subWidgetRect

        **QRectF QGraphicsProxyWidget::subWidgetRect(const QWidget * widget )
        const**

        Returns the rectangle for **widget** , which must be a descendant of
        **widget** (), or **widget** () itself, in this proxy item's local
        coordinates.

        If no widget is embedded, **widget** is `nullptr`, or **widget** is not
        a descendant of the embedded widget, this function returns an empty
        **QRectF** .

        **See also** **widget** ().
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#widget

        **QWidget *QGraphicsProxyWidget::widget() const**

        Returns a pointer to the embedded widget.

        **See also** **setWidget** ().
        """
        ...

    def setWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsproxywidget.html#setWidget

        **void QGraphicsProxyWidget::setWidget(QWidget * widget )**

        Embeds **widget** into this proxy widget. The embedded widget must
        reside exclusively either inside or outside of Graphics View. You cannot
        embed a widget as long as it is is visible elsewhere in the UI, at the
        same time.

        **widget** must be a top-level widget whose parent is `nullptr`.

        When the widget is embedded, its state (e.g., visible, enabled,
        geometry, size hints) is copied into the proxy widget. If the embedded
        widget is explicitly hidden or disabled, the proxy widget will become
        explicitly hidden or disabled after embedding is complete. The class
        documentation has a full overview over the shared state.

        **QGraphicsProxyWidget** 's window flags determine whether the widget,
        after embedding, will be given window decorations or not.

        After this function returns, **QGraphicsProxyWidget**  will keep its
        state synchronized with that of **widget** whenever possible.

        If a widget is already embedded by this proxy when this function is
        called, that widget will first be automatically unembedded. Passing
        `nullptr` for the **widget** argument will only unembed the widget, and
        the ownership of the currently embedded widget will be passed on to the
        caller. Every child widget that are embedded will also be embedded and
        their proxy widget destroyed.

        Note that widgets with the **Qt::WA_PaintOnScreen**  widget attribute
        set and widgets that wrap an external application or controller cannot
        be embedded. Examples are QOpenGLWidget and QAxWidget.

        **See also** **widget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtMultimedia
from PyQt6 import QtCore
from PyQt6.QtMultimediaWidgets import *


class QVideoWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qvideowidget.html

    **Detailed Description**

    Attaching a QVideoWidget to a **QMediaPlayer**  or **QCamera**  allows it to
    display the video or image output of that object.

    player = new **QMediaPlayer** ;
        player->setSource(**QUrl**
    ("http://example.com/myclip1.mp4"));

        videoWidget = new
    **QVideoWidget** ;
        player->setVideoOutput(videoWidget);
    videoWidget->show();
        player->play();

    **Note** : Only a single display output can be attached to a media object at
    one time.

    **See also** **QCamera** , **QMediaPlayer** , and **QGraphicsVideoItem** .
    """

    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#QVideoWidget

        **QVideoWidget::QVideoWidget(QWidget * parent = nullptr)**

        Constructs a new video widget.

        The **parent** is passed to **QWidget** .
        """
        ...

    def moveEvent(self, event: QtGui.QMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#moveEvent

        **[override virtual protected] void QVideoWidget::moveEvent(QMoveEvent *
        event )**

        Reimplements: **QWidget::moveEvent** (QMoveEvent *event).

        Handles the move **event**.
        """
        ...

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#resizeEvent

        **[override virtual protected] void
        QVideoWidget::resizeEvent(QResizeEvent * event )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).

        Handles the resize **event**.
        """
        ...

    def hideEvent(self, event: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#hideEvent

        **[override virtual protected] void QVideoWidget::hideEvent(QHideEvent *
        event )**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).

        Handles the hide **event**.
        """
        ...

    def showEvent(self, event: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#showEvent

        **[override virtual protected] void QVideoWidget::showEvent(QShowEvent *
        event )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).

        Handles the show **event**.
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#event

        **[override virtual protected] bool QVideoWidget::event(QEvent * event
        )**

        Reimplements: **QWidget::event** (QEvent *event).

        Current event **event**. Returns the value of the base class
        **QWidget::event** (**QEvent**  *event) function.
        """
        ...

    def setAspectRatioMode(self, mode: QtCore.Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#aspectRatioMode-prop

        **aspectRatioMode : Qt::AspectRatioMode**

        how video is scaled with respect to its aspect ratio.

        **Access functions:**

        Qt::AspectRatioMode **aspectRatioMode** () const
        void
        **setAspectRatioMode** (Qt::AspectRatioMode **mode** )

        **Notifier signal:**

        void **aspectRatioModeChanged** (Qt::AspectRatioMode **mode** )
        """
        ...

    def setFullScreen(self, fullScreen: bool) -> None:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#fullScreen-prop

        **fullScreen : bool**

        This property holds whether video display is confined to a window or is
        fullScreen.

        **Access functions:**

        bool **isFullScreen** () const
        void **setFullScreen** (bool
        **fullScreen** )

        **Notifier signal:**

        void ****fullScreenChanged** ** (bool **fullScreen** )

        **Member Function Documentation**
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#sizeHint

        **[override virtual] QSize QVideoWidget::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .

        Returns the size hint for the current back end, if there is one, or else
        the size hint from **QWidget** .
        """
        ...

    def isFullScreen(self) -> bool:
        ...

    def aspectRatioMode(self) -> QtCore.Qt.AspectRatioMode:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#aspectRatioMode-prop

        **aspectRatioMode : Qt::AspectRatioMode**

        how video is scaled with respect to its aspect ratio.

        **Access functions:**

        Qt::AspectRatioMode **aspectRatioMode** () const
        void
        **setAspectRatioMode** (Qt::AspectRatioMode **mode** )

        **Notifier signal:**

        void **aspectRatioModeChanged** (Qt::AspectRatioMode **mode** )
        """
        ...

    def videoSink(self) -> QtMultimedia.QVideoSink:
        ...

    @property
    def aspectRatioModeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def fullScreenChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qvideowidget.html#fullScreenChanged

        **[signal] void QVideoWidget::fullScreenChanged(bool fullScreen )**

        Signals that the **fullScreen** mode of a video widget has changed.

        **Note:** Notifier signal for property **fullScreen** .

        **See also** **isFullScreen** ().
        """
        ...
